@@ -1,16 +1,16 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: address.py 662 2009-11-07 14:26:15Z icemac $
-
-import persistent
-import zope.container.contained
-import zope.interface
-import zope.schema.fieldproperty
-import icemac.addressbook.entities
-import icemac.addressbook.interfaces
+# $Id: address.py 756 2009-12-28 19:38:47Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
+import icemac.addressbook.entities
+import icemac.addressbook.interfaces
+import persistent
+import zope.container.contained
+import zope.globalrequest
+import zope.interface
+import zope.schema.fieldproperty
 
 
 class PostalAddress(
@@ -45,7 +45,13 @@ def postal_address_title(address):
               for x in ('address_prefix', 'street', 'zip', 'city', 'country')
               if getattr(address, x)]
     if values:
-        title = ', '.join(values)
+        request = zope.globalrequest.getRequest()
+        translated_values = []
+        for val in values:
+            if isinstance(val, zope.i18nmessageid.Message):
+                val = zope.i18n.translate(val, context=request)
+            translated_values.append(val)
+        title = ', '.join(translated_values)
     return title
 
 class EMailAddress(
@@ -125,19 +131,19 @@ def phone_number_title(tel):
 # title is no i18n message id as it get concatenated later on
 address_mapping = (
     dict(interface=icemac.addressbook.interfaces.IPostalAddress,
-         title=u'postal address',
+         title=_(u'postal address'),
          prefix='postal_address',
          class_=PostalAddress),
     dict(interface=icemac.addressbook.interfaces.IPhoneNumber,
-         title=u'phone number',
+         title=_(u'phone number'),
          prefix='phone_number',
          class_=PhoneNumber),
     dict(interface=icemac.addressbook.interfaces.IEMailAddress,
-         title=u'e-mail address',
+         title=_(u'e-mail address'),
          prefix='email_address',
          class_=EMailAddress),
     dict(interface=icemac.addressbook.interfaces.IHomePageAddress,
-         title=u'home page address',
+         title=_(u'home page address'),
          prefix='home_page_address',
          class_=HomePageAddress),
     )
