@@ -1,12 +1,13 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: person.py 1184 2009-05-12 18:39:39Z mac $
+# $Id: person.py 756 2009-12-28 19:38:47Z icemac $
 
-from icemac.addressbook.address import interface_title_prefix_class_mapping
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.reference.interfaces
+import icemac.addressbook.address
 import icemac.addressbook.browser.base
+import icemac.addressbook.browser.metadata
 import icemac.addressbook.interfaces
 import icemac.addressbook.person
 import icemac.addressbook.sources
@@ -15,13 +16,7 @@ import z3c.form.button
 import z3c.form.datamanager
 import z3c.form.group
 import zc.sourcefactory.contextual
-import zope.component
-import zope.traversing.browser.interfaces
-
-
-def prefix_to_class(prefix):
-    mapping = dict((x[2], x[3]) for x in interface_title_prefix_class_mapping)
-    return mapping[prefix]
+import zope.interface
 
 
 class AddGroup(icemac.addressbook.browser.base.PrefixGroup):
@@ -37,6 +32,8 @@ class AddGroup(icemac.addressbook.browser.base.PrefixGroup):
 class EditGroup(AddGroup):
     "PrefixGroup for EditForm."
 
+    groups = (icemac.addressbook.browser.metadata.ModifiedGroup,)
+
     def __init__(
         self, context, request, parent, interface, label, prefix, index, key):
         super(EditGroup, self).__init__(
@@ -75,9 +72,9 @@ class PersonAddForm(z3c.form.group.GroupForm,
         super(PersonAddForm, self).__init__(*args, **kw)
         context = self.context
         request = self.request
-        groups = [AddGroup(context, request, self, iface, _(title), prefix)
-                  for iface, title, prefix, dummy in
-                      interface_title_prefix_class_mapping]
+        groups = [AddGroup(context, request, self, address['interface'],
+                           _(address['title']), address['prefix'])
+                  for address in icemac.addressbook.address.address_mapping]
         self.groups = tuple(groups)
 
     def createAndAdd(self, data):
@@ -86,7 +83,8 @@ class PersonAddForm(z3c.form.group.GroupForm,
         self._name = icemac.addressbook.utils.add(self.context, person)
         for group in self.groups:
             obj = icemac.addressbook.browser.base.create(
-                group, prefix_to_class(group.prefix), data)
+                group, icemac.addressbook.address.prefix_to_class(group.prefix),
+                data)
             icemac.addressbook.utils.add(person, obj)
             # handling of default addresses: the first address is
             # saved as default
@@ -112,19 +110,22 @@ class PersonEditForm(
 
     def __init__(self, *args, **kw):
         super(PersonEditForm, self).__init__(*args, **kw)
-        groups = [DefaultSelectGroup]
-        for iface, title, prefix, dummy in interface_title_prefix_class_mapping:
+        groups = [icemac.addressbook.browser.metadata.ModifiedGroup,
+                  DefaultSelectGroup]
+        for address in icemac.addressbook.address.address_mapping:
             index = 0
-            default_obj = getattr(self.context, 'default_%s' % prefix)
+            default_obj = getattr(self.context,
+                                  'default_%s' % address['prefix'])
             for obj in icemac.addressbook.utils.iter_by_interface(
-                    self.context, iface):
+                    self.context, address['interface']):
                 if obj == default_obj:
-                    obj_title = u'main ' + title
+                    obj_title = _(u'main ${address}')
                 else:
-                    obj_title = u'other ' + title
+                    obj_title = _(u'other ${address}')
+                obj_title = _(obj_title, mapping={'address': address['title']})
                 group = EditGroup(
-                    self.context, self.request, self, iface, _(obj_title),
-                    prefix, index, obj.__name__)
+                    self.context, self.request, self, address['interface'],
+                    obj_title, address['prefix'], index, obj.__name__)
                 groups.append(group)
                 index += 1
 
@@ -160,20 +161,14 @@ class PersonEditForm(
             icemac.addressbook.browser.base.can_access('@@delete_person.html'),
             person_deletable))
     def handleDeletePerson(self, action):
-        url = zope.component.getMultiAdapter(
-            (self.context, self.request),
-            zope.traversing.browser.interfaces.IAbsoluteURL)()
-        self.request.response.redirect(url + '/@@delete_person.html')
+        self.redirect_to_next_url('object', '@@delete_person.html')
 
     @z3c.form.button.buttonAndHandler(
         _(u'Delete single entry'), name='delete_entry',
         condition=icemac.addressbook.browser.base.can_access(
             '@@delete_entry.html'))
     def handleDeleteAddress(self, action):
-        url = zope.component.getMultiAdapter(
-            (self.context, self.request),
-            zope.traversing.browser.interfaces.IAbsoluteURL)()
-        self.request.response.redirect(url + '/@@delete_entry.html')
+        self.redirect_to_next_url('object', '@@delete_entry.html')
 
 
 class KeywordDataManager(z3c.form.datamanager.AttributeField):
@@ -206,9 +201,9 @@ class PersonEntriesSource(
     "Source to select entries from person."
 
     def getValues(self, context):
-        for interface, d, d, d in interface_title_prefix_class_mapping:
+        for address in icemac.addressbook.address.address_mapping:
             for value in icemac.addressbook.sources.ContextByInterfaceSource(
-                interface).factory.getValues(context):
+                    address['interface']).factory.getValues(context):
                 yield value
         for value in icemac.addressbook.sources.ContextByInterfaceSource(
             icemac.addressbook.file.interfaces.IFile).factory.getValues(
@@ -223,7 +218,8 @@ class PersonEntriesSource(
             title_prefix = _('file')
         title = icemac.addressbook.interfaces.ITitle(value)
         if title_prefix:
-            title = '%s -- %s' % (title_prefix, title)
+            title = _('${prefix} -- ${title}',
+                      mapping=dict(prefix=title_prefix, title=title))
         return title
 
 
@@ -235,6 +231,7 @@ class IPersonEntries(zope.interface.Interface):
 
 
 class DeleteSingleEntryForm(icemac.addressbook.browser.base.BaseEditForm):
+    "Form to choose entry for deletion."
 
     label = _(u'Please choose an entry for deletion:')
     interface = IPersonEntries
@@ -249,9 +246,7 @@ class DeleteSingleEntryForm(icemac.addressbook.browser.base.BaseEditForm):
             return
         selected_entry = data['entry']
 
-        url = zope.component.getMultiAdapter(
-            (selected_entry, self.request),
-            zope.traversing.browser.interfaces.IAbsoluteURL)()
+        url = self.url(selected_entry)
         self.request.response.redirect(url + '/@@delete.html')
 
     @z3c.form.button.buttonAndHandler(_(u'Cancel'), name='cancel')
